"""
Type annotations for ivs-realtime service client paginators.

[Documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/paginators/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session

    from mypy_boto3_ivs_realtime.client import IvsrealtimeClient
    from mypy_boto3_ivs_realtime.paginator import (
        ListIngestConfigurationsPaginator,
        ListParticipantReplicasPaginator,
        ListPublicKeysPaginator,
    )

    session = Session()
    client: IvsrealtimeClient = session.client("ivs-realtime")

    list_ingest_configurations_paginator: ListIngestConfigurationsPaginator = client.get_paginator("list_ingest_configurations")
    list_participant_replicas_paginator: ListParticipantReplicasPaginator = client.get_paginator("list_participant_replicas")
    list_public_keys_paginator: ListPublicKeysPaginator = client.get_paginator("list_public_keys")
    ```
"""

from __future__ import annotations

import sys
from typing import TYPE_CHECKING

from botocore.paginate import PageIterator, Paginator

from .type_defs import (
    ListIngestConfigurationsRequestPaginateTypeDef,
    ListIngestConfigurationsResponseTypeDef,
    ListParticipantReplicasRequestPaginateTypeDef,
    ListParticipantReplicasResponseTypeDef,
    ListPublicKeysRequestPaginateTypeDef,
    ListPublicKeysResponseTypeDef,
)

if sys.version_info >= (3, 12):
    from typing import Unpack
else:
    from typing_extensions import Unpack


__all__ = (
    "ListIngestConfigurationsPaginator",
    "ListParticipantReplicasPaginator",
    "ListPublicKeysPaginator",
)


if TYPE_CHECKING:
    _ListIngestConfigurationsPaginatorBase = Paginator[ListIngestConfigurationsResponseTypeDef]
else:
    _ListIngestConfigurationsPaginatorBase = Paginator  # type: ignore[assignment]


class ListIngestConfigurationsPaginator(_ListIngestConfigurationsPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/paginator/ListIngestConfigurations.html#Ivsrealtime.Paginator.ListIngestConfigurations)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/paginators/#listingestconfigurationspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListIngestConfigurationsRequestPaginateTypeDef]
    ) -> PageIterator[ListIngestConfigurationsResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/paginator/ListIngestConfigurations.html#Ivsrealtime.Paginator.ListIngestConfigurations.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/paginators/#listingestconfigurationspaginator)
        """


if TYPE_CHECKING:
    _ListParticipantReplicasPaginatorBase = Paginator[ListParticipantReplicasResponseTypeDef]
else:
    _ListParticipantReplicasPaginatorBase = Paginator  # type: ignore[assignment]


class ListParticipantReplicasPaginator(_ListParticipantReplicasPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/paginator/ListParticipantReplicas.html#Ivsrealtime.Paginator.ListParticipantReplicas)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/paginators/#listparticipantreplicaspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListParticipantReplicasRequestPaginateTypeDef]
    ) -> PageIterator[ListParticipantReplicasResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/paginator/ListParticipantReplicas.html#Ivsrealtime.Paginator.ListParticipantReplicas.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/paginators/#listparticipantreplicaspaginator)
        """


if TYPE_CHECKING:
    _ListPublicKeysPaginatorBase = Paginator[ListPublicKeysResponseTypeDef]
else:
    _ListPublicKeysPaginatorBase = Paginator  # type: ignore[assignment]


class ListPublicKeysPaginator(_ListPublicKeysPaginatorBase):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/paginator/ListPublicKeys.html#Ivsrealtime.Paginator.ListPublicKeys)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/paginators/#listpublickeyspaginator)
    """

    def paginate(  # type: ignore[override]
        self, **kwargs: Unpack[ListPublicKeysRequestPaginateTypeDef]
    ) -> PageIterator[ListPublicKeysResponseTypeDef]:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/paginator/ListPublicKeys.html#Ivsrealtime.Paginator.ListPublicKeys.paginate)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/paginators/#listpublickeyspaginator)
        """



"""
Type annotations for ivs-realtime service type definitions.

[Documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/type_defs/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from mypy_boto3_ivs_realtime.type_defs import ParticipantRecordingHlsConfigurationTypeDef

    data: ParticipantRecordingHlsConfigurationTypeDef = ...
    ```
"""

from __future__ import annotations

import sys
from datetime import datetime
from typing import Union

from .literals import (
    CompositionStateType,
    DestinationStateType,
    EventErrorCodeType,
    EventNameType,
    IngestConfigurationStateType,
    IngestProtocolType,
    ParticipantProtocolType,
    ParticipantRecordingFilterByRecordingStateType,
    ParticipantRecordingMediaTypeType,
    ParticipantRecordingStateType,
    ParticipantStateType,
    ParticipantTokenCapabilityType,
    PipBehaviorType,
    PipPositionType,
    ReplicationStateType,
    ReplicationTypeType,
    ThumbnailRecordingModeType,
    ThumbnailStorageTypeType,
    VideoAspectRatioType,
    VideoFillModeType,
)

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
    from builtins import list as List
    from collections.abc import Mapping, Sequence
else:
    from typing import Dict, List, Mapping, Sequence
if sys.version_info >= (3, 12):
    from typing import Literal, NotRequired, TypedDict
else:
    from typing_extensions import Literal, NotRequired, TypedDict

__all__ = (
    "AutoParticipantRecordingConfigurationOutputTypeDef",
    "AutoParticipantRecordingConfigurationTypeDef",
    "AutoParticipantRecordingConfigurationUnionTypeDef",
    "ChannelDestinationConfigurationTypeDef",
    "CompositionRecordingHlsConfigurationTypeDef",
    "CompositionSummaryTypeDef",
    "CompositionThumbnailConfigurationOutputTypeDef",
    "CompositionThumbnailConfigurationTypeDef",
    "CompositionThumbnailConfigurationUnionTypeDef",
    "CompositionTypeDef",
    "CreateEncoderConfigurationRequestTypeDef",
    "CreateEncoderConfigurationResponseTypeDef",
    "CreateIngestConfigurationRequestTypeDef",
    "CreateIngestConfigurationResponseTypeDef",
    "CreateParticipantTokenRequestTypeDef",
    "CreateParticipantTokenResponseTypeDef",
    "CreateStageRequestTypeDef",
    "CreateStageResponseTypeDef",
    "CreateStorageConfigurationRequestTypeDef",
    "CreateStorageConfigurationResponseTypeDef",
    "DeleteEncoderConfigurationRequestTypeDef",
    "DeleteIngestConfigurationRequestTypeDef",
    "DeletePublicKeyRequestTypeDef",
    "DeleteStageRequestTypeDef",
    "DeleteStorageConfigurationRequestTypeDef",
    "DestinationConfigurationOutputTypeDef",
    "DestinationConfigurationTypeDef",
    "DestinationConfigurationUnionTypeDef",
    "DestinationDetailTypeDef",
    "DestinationSummaryTypeDef",
    "DestinationTypeDef",
    "DisconnectParticipantRequestTypeDef",
    "EncoderConfigurationSummaryTypeDef",
    "EncoderConfigurationTypeDef",
    "EventTypeDef",
    "GetCompositionRequestTypeDef",
    "GetCompositionResponseTypeDef",
    "GetEncoderConfigurationRequestTypeDef",
    "GetEncoderConfigurationResponseTypeDef",
    "GetIngestConfigurationRequestTypeDef",
    "GetIngestConfigurationResponseTypeDef",
    "GetParticipantRequestTypeDef",
    "GetParticipantResponseTypeDef",
    "GetPublicKeyRequestTypeDef",
    "GetPublicKeyResponseTypeDef",
    "GetStageRequestTypeDef",
    "GetStageResponseTypeDef",
    "GetStageSessionRequestTypeDef",
    "GetStageSessionResponseTypeDef",
    "GetStorageConfigurationRequestTypeDef",
    "GetStorageConfigurationResponseTypeDef",
    "GridConfigurationTypeDef",
    "ImportPublicKeyRequestTypeDef",
    "ImportPublicKeyResponseTypeDef",
    "IngestConfigurationSummaryTypeDef",
    "IngestConfigurationTypeDef",
    "LayoutConfigurationTypeDef",
    "ListCompositionsRequestTypeDef",
    "ListCompositionsResponseTypeDef",
    "ListEncoderConfigurationsRequestTypeDef",
    "ListEncoderConfigurationsResponseTypeDef",
    "ListIngestConfigurationsRequestPaginateTypeDef",
    "ListIngestConfigurationsRequestTypeDef",
    "ListIngestConfigurationsResponseTypeDef",
    "ListParticipantEventsRequestTypeDef",
    "ListParticipantEventsResponseTypeDef",
    "ListParticipantReplicasRequestPaginateTypeDef",
    "ListParticipantReplicasRequestTypeDef",
    "ListParticipantReplicasResponseTypeDef",
    "ListParticipantsRequestTypeDef",
    "ListParticipantsResponseTypeDef",
    "ListPublicKeysRequestPaginateTypeDef",
    "ListPublicKeysRequestTypeDef",
    "ListPublicKeysResponseTypeDef",
    "ListStageSessionsRequestTypeDef",
    "ListStageSessionsResponseTypeDef",
    "ListStagesRequestTypeDef",
    "ListStagesResponseTypeDef",
    "ListStorageConfigurationsRequestTypeDef",
    "ListStorageConfigurationsResponseTypeDef",
    "ListTagsForResourceRequestTypeDef",
    "ListTagsForResourceResponseTypeDef",
    "PaginatorConfigTypeDef",
    "ParticipantRecordingHlsConfigurationTypeDef",
    "ParticipantReplicaTypeDef",
    "ParticipantSummaryTypeDef",
    "ParticipantThumbnailConfigurationOutputTypeDef",
    "ParticipantThumbnailConfigurationTypeDef",
    "ParticipantTokenConfigurationTypeDef",
    "ParticipantTokenTypeDef",
    "ParticipantTypeDef",
    "PipConfigurationTypeDef",
    "PublicKeySummaryTypeDef",
    "PublicKeyTypeDef",
    "RecordingConfigurationTypeDef",
    "ResponseMetadataTypeDef",
    "S3DestinationConfigurationOutputTypeDef",
    "S3DestinationConfigurationTypeDef",
    "S3DestinationConfigurationUnionTypeDef",
    "S3DetailTypeDef",
    "S3StorageConfigurationTypeDef",
    "StageEndpointsTypeDef",
    "StageSessionSummaryTypeDef",
    "StageSessionTypeDef",
    "StageSummaryTypeDef",
    "StageTypeDef",
    "StartCompositionRequestTypeDef",
    "StartCompositionResponseTypeDef",
    "StartParticipantReplicationRequestTypeDef",
    "StartParticipantReplicationResponseTypeDef",
    "StopCompositionRequestTypeDef",
    "StopParticipantReplicationRequestTypeDef",
    "StopParticipantReplicationResponseTypeDef",
    "StorageConfigurationSummaryTypeDef",
    "StorageConfigurationTypeDef",
    "TagResourceRequestTypeDef",
    "UntagResourceRequestTypeDef",
    "UpdateIngestConfigurationRequestTypeDef",
    "UpdateIngestConfigurationResponseTypeDef",
    "UpdateStageRequestTypeDef",
    "UpdateStageResponseTypeDef",
    "VideoTypeDef",
)

class ParticipantRecordingHlsConfigurationTypeDef(TypedDict):
    targetSegmentDurationSeconds: NotRequired[int]

class ParticipantThumbnailConfigurationOutputTypeDef(TypedDict):
    targetIntervalSeconds: NotRequired[int]
    storage: NotRequired[List[ThumbnailStorageTypeType]]
    recordingMode: NotRequired[ThumbnailRecordingModeType]

class ParticipantThumbnailConfigurationTypeDef(TypedDict):
    targetIntervalSeconds: NotRequired[int]
    storage: NotRequired[Sequence[ThumbnailStorageTypeType]]
    recordingMode: NotRequired[ThumbnailRecordingModeType]

class ChannelDestinationConfigurationTypeDef(TypedDict):
    channelArn: str
    encoderConfigurationArn: NotRequired[str]

class CompositionRecordingHlsConfigurationTypeDef(TypedDict):
    targetSegmentDurationSeconds: NotRequired[int]

DestinationSummaryTypeDef = TypedDict(
    "DestinationSummaryTypeDef",
    {
        "id": str,
        "state": DestinationStateType,
        "startTime": NotRequired[datetime],
        "endTime": NotRequired[datetime],
    },
)

class CompositionThumbnailConfigurationOutputTypeDef(TypedDict):
    targetIntervalSeconds: NotRequired[int]
    storage: NotRequired[List[ThumbnailStorageTypeType]]

class CompositionThumbnailConfigurationTypeDef(TypedDict):
    targetIntervalSeconds: NotRequired[int]
    storage: NotRequired[Sequence[ThumbnailStorageTypeType]]

class VideoTypeDef(TypedDict):
    width: NotRequired[int]
    height: NotRequired[int]
    framerate: NotRequired[float]
    bitrate: NotRequired[int]

class ResponseMetadataTypeDef(TypedDict):
    RequestId: str
    HTTPStatusCode: int
    HTTPHeaders: Dict[str, str]
    RetryAttempts: int
    HostId: NotRequired[str]

class CreateIngestConfigurationRequestTypeDef(TypedDict):
    ingestProtocol: IngestProtocolType
    name: NotRequired[str]
    stageArn: NotRequired[str]
    userId: NotRequired[str]
    attributes: NotRequired[Mapping[str, str]]
    insecureIngest: NotRequired[bool]
    tags: NotRequired[Mapping[str, str]]

class IngestConfigurationTypeDef(TypedDict):
    arn: str
    ingestProtocol: IngestProtocolType
    streamKey: str
    stageArn: str
    participantId: str
    state: IngestConfigurationStateType
    name: NotRequired[str]
    userId: NotRequired[str]
    attributes: NotRequired[Dict[str, str]]
    tags: NotRequired[Dict[str, str]]

class CreateParticipantTokenRequestTypeDef(TypedDict):
    stageArn: str
    duration: NotRequired[int]
    userId: NotRequired[str]
    attributes: NotRequired[Mapping[str, str]]
    capabilities: NotRequired[Sequence[ParticipantTokenCapabilityType]]

class ParticipantTokenTypeDef(TypedDict):
    participantId: NotRequired[str]
    token: NotRequired[str]
    userId: NotRequired[str]
    attributes: NotRequired[Dict[str, str]]
    duration: NotRequired[int]
    capabilities: NotRequired[List[ParticipantTokenCapabilityType]]
    expirationTime: NotRequired[datetime]

class ParticipantTokenConfigurationTypeDef(TypedDict):
    duration: NotRequired[int]
    userId: NotRequired[str]
    attributes: NotRequired[Mapping[str, str]]
    capabilities: NotRequired[Sequence[ParticipantTokenCapabilityType]]

class S3StorageConfigurationTypeDef(TypedDict):
    bucketName: str

class DeleteEncoderConfigurationRequestTypeDef(TypedDict):
    arn: str

class DeleteIngestConfigurationRequestTypeDef(TypedDict):
    arn: str
    force: NotRequired[bool]

class DeletePublicKeyRequestTypeDef(TypedDict):
    arn: str

class DeleteStageRequestTypeDef(TypedDict):
    arn: str

class DeleteStorageConfigurationRequestTypeDef(TypedDict):
    arn: str

class S3DetailTypeDef(TypedDict):
    recordingPrefix: str

class DisconnectParticipantRequestTypeDef(TypedDict):
    stageArn: str
    participantId: str
    reason: NotRequired[str]

class EncoderConfigurationSummaryTypeDef(TypedDict):
    arn: str
    name: NotRequired[str]
    tags: NotRequired[Dict[str, str]]

class EventTypeDef(TypedDict):
    name: NotRequired[EventNameType]
    participantId: NotRequired[str]
    eventTime: NotRequired[datetime]
    remoteParticipantId: NotRequired[str]
    errorCode: NotRequired[EventErrorCodeType]
    destinationStageArn: NotRequired[str]
    destinationSessionId: NotRequired[str]
    replica: NotRequired[bool]

class GetCompositionRequestTypeDef(TypedDict):
    arn: str

class GetEncoderConfigurationRequestTypeDef(TypedDict):
    arn: str

class GetIngestConfigurationRequestTypeDef(TypedDict):
    arn: str

class GetParticipantRequestTypeDef(TypedDict):
    stageArn: str
    sessionId: str
    participantId: str

class ParticipantTypeDef(TypedDict):
    participantId: NotRequired[str]
    userId: NotRequired[str]
    state: NotRequired[ParticipantStateType]
    firstJoinTime: NotRequired[datetime]
    attributes: NotRequired[Dict[str, str]]
    published: NotRequired[bool]
    ispName: NotRequired[str]
    osName: NotRequired[str]
    osVersion: NotRequired[str]
    browserName: NotRequired[str]
    browserVersion: NotRequired[str]
    sdkVersion: NotRequired[str]
    recordingS3BucketName: NotRequired[str]
    recordingS3Prefix: NotRequired[str]
    recordingState: NotRequired[ParticipantRecordingStateType]
    protocol: NotRequired[ParticipantProtocolType]
    replicationType: NotRequired[ReplicationTypeType]
    replicationState: NotRequired[ReplicationStateType]
    sourceStageArn: NotRequired[str]
    sourceSessionId: NotRequired[str]

class GetPublicKeyRequestTypeDef(TypedDict):
    arn: str

class PublicKeyTypeDef(TypedDict):
    arn: NotRequired[str]
    name: NotRequired[str]
    publicKeyMaterial: NotRequired[str]
    fingerprint: NotRequired[str]
    tags: NotRequired[Dict[str, str]]

class GetStageRequestTypeDef(TypedDict):
    arn: str

class GetStageSessionRequestTypeDef(TypedDict):
    stageArn: str
    sessionId: str

class StageSessionTypeDef(TypedDict):
    sessionId: NotRequired[str]
    startTime: NotRequired[datetime]
    endTime: NotRequired[datetime]

class GetStorageConfigurationRequestTypeDef(TypedDict):
    arn: str

class GridConfigurationTypeDef(TypedDict):
    featuredParticipantAttribute: NotRequired[str]
    omitStoppedVideo: NotRequired[bool]
    videoAspectRatio: NotRequired[VideoAspectRatioType]
    videoFillMode: NotRequired[VideoFillModeType]
    gridGap: NotRequired[int]

class ImportPublicKeyRequestTypeDef(TypedDict):
    publicKeyMaterial: str
    name: NotRequired[str]
    tags: NotRequired[Mapping[str, str]]

class IngestConfigurationSummaryTypeDef(TypedDict):
    arn: str
    ingestProtocol: IngestProtocolType
    stageArn: str
    participantId: str
    state: IngestConfigurationStateType
    name: NotRequired[str]
    userId: NotRequired[str]

class PipConfigurationTypeDef(TypedDict):
    featuredParticipantAttribute: NotRequired[str]
    omitStoppedVideo: NotRequired[bool]
    videoFillMode: NotRequired[VideoFillModeType]
    gridGap: NotRequired[int]
    pipParticipantAttribute: NotRequired[str]
    pipBehavior: NotRequired[PipBehaviorType]
    pipOffset: NotRequired[int]
    pipPosition: NotRequired[PipPositionType]
    pipWidth: NotRequired[int]
    pipHeight: NotRequired[int]

class ListCompositionsRequestTypeDef(TypedDict):
    filterByStageArn: NotRequired[str]
    filterByEncoderConfigurationArn: NotRequired[str]
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class ListEncoderConfigurationsRequestTypeDef(TypedDict):
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class PaginatorConfigTypeDef(TypedDict):
    MaxItems: NotRequired[int]
    PageSize: NotRequired[int]
    StartingToken: NotRequired[str]

class ListIngestConfigurationsRequestTypeDef(TypedDict):
    filterByStageArn: NotRequired[str]
    filterByState: NotRequired[IngestConfigurationStateType]
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class ListParticipantEventsRequestTypeDef(TypedDict):
    stageArn: str
    sessionId: str
    participantId: str
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class ListParticipantReplicasRequestTypeDef(TypedDict):
    sourceStageArn: str
    participantId: str
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class ParticipantReplicaTypeDef(TypedDict):
    sourceStageArn: str
    participantId: str
    sourceSessionId: str
    destinationStageArn: str
    destinationSessionId: str
    replicationState: ReplicationStateType

class ListParticipantsRequestTypeDef(TypedDict):
    stageArn: str
    sessionId: str
    filterByUserId: NotRequired[str]
    filterByPublished: NotRequired[bool]
    filterByState: NotRequired[ParticipantStateType]
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]
    filterByRecordingState: NotRequired[ParticipantRecordingFilterByRecordingStateType]

class ParticipantSummaryTypeDef(TypedDict):
    participantId: NotRequired[str]
    userId: NotRequired[str]
    state: NotRequired[ParticipantStateType]
    firstJoinTime: NotRequired[datetime]
    published: NotRequired[bool]
    recordingState: NotRequired[ParticipantRecordingStateType]
    replicationType: NotRequired[ReplicationTypeType]
    replicationState: NotRequired[ReplicationStateType]
    sourceStageArn: NotRequired[str]
    sourceSessionId: NotRequired[str]

class ListPublicKeysRequestTypeDef(TypedDict):
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class PublicKeySummaryTypeDef(TypedDict):
    arn: NotRequired[str]
    name: NotRequired[str]
    tags: NotRequired[Dict[str, str]]

class ListStageSessionsRequestTypeDef(TypedDict):
    stageArn: str
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class StageSessionSummaryTypeDef(TypedDict):
    sessionId: NotRequired[str]
    startTime: NotRequired[datetime]
    endTime: NotRequired[datetime]

class ListStagesRequestTypeDef(TypedDict):
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class StageSummaryTypeDef(TypedDict):
    arn: str
    name: NotRequired[str]
    activeSessionId: NotRequired[str]
    tags: NotRequired[Dict[str, str]]

class ListStorageConfigurationsRequestTypeDef(TypedDict):
    nextToken: NotRequired[str]
    maxResults: NotRequired[int]

class ListTagsForResourceRequestTypeDef(TypedDict):
    resourceArn: str

class StageEndpointsTypeDef(TypedDict):
    events: NotRequired[str]
    whip: NotRequired[str]
    rtmp: NotRequired[str]
    rtmps: NotRequired[str]

class StartParticipantReplicationRequestTypeDef(TypedDict):
    sourceStageArn: str
    destinationStageArn: str
    participantId: str
    reconnectWindowSeconds: NotRequired[int]
    attributes: NotRequired[Mapping[str, str]]

class StopCompositionRequestTypeDef(TypedDict):
    arn: str

class StopParticipantReplicationRequestTypeDef(TypedDict):
    sourceStageArn: str
    destinationStageArn: str
    participantId: str

class TagResourceRequestTypeDef(TypedDict):
    resourceArn: str
    tags: Mapping[str, str]

class UntagResourceRequestTypeDef(TypedDict):
    resourceArn: str
    tagKeys: Sequence[str]

class UpdateIngestConfigurationRequestTypeDef(TypedDict):
    arn: str
    stageArn: NotRequired[str]

class AutoParticipantRecordingConfigurationOutputTypeDef(TypedDict):
    storageConfigurationArn: str
    mediaTypes: NotRequired[List[ParticipantRecordingMediaTypeType]]
    thumbnailConfiguration: NotRequired[ParticipantThumbnailConfigurationOutputTypeDef]
    recordingReconnectWindowSeconds: NotRequired[int]
    hlsConfiguration: NotRequired[ParticipantRecordingHlsConfigurationTypeDef]
    recordParticipantReplicas: NotRequired[bool]

class AutoParticipantRecordingConfigurationTypeDef(TypedDict):
    storageConfigurationArn: str
    mediaTypes: NotRequired[Sequence[ParticipantRecordingMediaTypeType]]
    thumbnailConfiguration: NotRequired[ParticipantThumbnailConfigurationTypeDef]
    recordingReconnectWindowSeconds: NotRequired[int]
    hlsConfiguration: NotRequired[ParticipantRecordingHlsConfigurationTypeDef]
    recordParticipantReplicas: NotRequired[bool]

RecordingConfigurationTypeDef = TypedDict(
    "RecordingConfigurationTypeDef",
    {
        "hlsConfiguration": NotRequired[CompositionRecordingHlsConfigurationTypeDef],
        "format": NotRequired[Literal["HLS"]],
    },
)

class CompositionSummaryTypeDef(TypedDict):
    arn: str
    stageArn: str
    destinations: List[DestinationSummaryTypeDef]
    state: CompositionStateType
    tags: NotRequired[Dict[str, str]]
    startTime: NotRequired[datetime]
    endTime: NotRequired[datetime]

CompositionThumbnailConfigurationUnionTypeDef = Union[
    CompositionThumbnailConfigurationTypeDef, CompositionThumbnailConfigurationOutputTypeDef
]

class CreateEncoderConfigurationRequestTypeDef(TypedDict):
    name: NotRequired[str]
    video: NotRequired[VideoTypeDef]
    tags: NotRequired[Mapping[str, str]]

class EncoderConfigurationTypeDef(TypedDict):
    arn: str
    name: NotRequired[str]
    video: NotRequired[VideoTypeDef]
    tags: NotRequired[Dict[str, str]]

class ListTagsForResourceResponseTypeDef(TypedDict):
    tags: Dict[str, str]
    ResponseMetadata: ResponseMetadataTypeDef

class StartParticipantReplicationResponseTypeDef(TypedDict):
    accessControlAllowOrigin: str
    accessControlExposeHeaders: str
    cacheControl: str
    contentSecurityPolicy: str
    strictTransportSecurity: str
    xContentTypeOptions: str
    xFrameOptions: str
    ResponseMetadata: ResponseMetadataTypeDef

class StopParticipantReplicationResponseTypeDef(TypedDict):
    accessControlAllowOrigin: str
    accessControlExposeHeaders: str
    cacheControl: str
    contentSecurityPolicy: str
    strictTransportSecurity: str
    xContentTypeOptions: str
    xFrameOptions: str
    ResponseMetadata: ResponseMetadataTypeDef

class CreateIngestConfigurationResponseTypeDef(TypedDict):
    ingestConfiguration: IngestConfigurationTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class GetIngestConfigurationResponseTypeDef(TypedDict):
    ingestConfiguration: IngestConfigurationTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class UpdateIngestConfigurationResponseTypeDef(TypedDict):
    ingestConfiguration: IngestConfigurationTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class CreateParticipantTokenResponseTypeDef(TypedDict):
    participantToken: ParticipantTokenTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class CreateStorageConfigurationRequestTypeDef(TypedDict):
    s3: S3StorageConfigurationTypeDef
    name: NotRequired[str]
    tags: NotRequired[Mapping[str, str]]

class StorageConfigurationSummaryTypeDef(TypedDict):
    arn: str
    name: NotRequired[str]
    s3: NotRequired[S3StorageConfigurationTypeDef]
    tags: NotRequired[Dict[str, str]]

class StorageConfigurationTypeDef(TypedDict):
    arn: str
    name: NotRequired[str]
    s3: NotRequired[S3StorageConfigurationTypeDef]
    tags: NotRequired[Dict[str, str]]

class DestinationDetailTypeDef(TypedDict):
    s3: NotRequired[S3DetailTypeDef]

class ListEncoderConfigurationsResponseTypeDef(TypedDict):
    encoderConfigurations: List[EncoderConfigurationSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class ListParticipantEventsResponseTypeDef(TypedDict):
    events: List[EventTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class GetParticipantResponseTypeDef(TypedDict):
    participant: ParticipantTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class GetPublicKeyResponseTypeDef(TypedDict):
    publicKey: PublicKeyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class ImportPublicKeyResponseTypeDef(TypedDict):
    publicKey: PublicKeyTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class GetStageSessionResponseTypeDef(TypedDict):
    stageSession: StageSessionTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class ListIngestConfigurationsResponseTypeDef(TypedDict):
    ingestConfigurations: List[IngestConfigurationSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class LayoutConfigurationTypeDef(TypedDict):
    grid: NotRequired[GridConfigurationTypeDef]
    pip: NotRequired[PipConfigurationTypeDef]

class ListIngestConfigurationsRequestPaginateTypeDef(TypedDict):
    filterByStageArn: NotRequired[str]
    filterByState: NotRequired[IngestConfigurationStateType]
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListParticipantReplicasRequestPaginateTypeDef(TypedDict):
    sourceStageArn: str
    participantId: str
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListPublicKeysRequestPaginateTypeDef(TypedDict):
    PaginationConfig: NotRequired[PaginatorConfigTypeDef]

class ListParticipantReplicasResponseTypeDef(TypedDict):
    replicas: List[ParticipantReplicaTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class ListParticipantsResponseTypeDef(TypedDict):
    participants: List[ParticipantSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class ListPublicKeysResponseTypeDef(TypedDict):
    publicKeys: List[PublicKeySummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class ListStageSessionsResponseTypeDef(TypedDict):
    stageSessions: List[StageSessionSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class ListStagesResponseTypeDef(TypedDict):
    stages: List[StageSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class StageTypeDef(TypedDict):
    arn: str
    name: NotRequired[str]
    activeSessionId: NotRequired[str]
    tags: NotRequired[Dict[str, str]]
    autoParticipantRecordingConfiguration: NotRequired[
        AutoParticipantRecordingConfigurationOutputTypeDef
    ]
    endpoints: NotRequired[StageEndpointsTypeDef]

AutoParticipantRecordingConfigurationUnionTypeDef = Union[
    AutoParticipantRecordingConfigurationTypeDef, AutoParticipantRecordingConfigurationOutputTypeDef
]

class S3DestinationConfigurationOutputTypeDef(TypedDict):
    storageConfigurationArn: str
    encoderConfigurationArns: List[str]
    recordingConfiguration: NotRequired[RecordingConfigurationTypeDef]
    thumbnailConfigurations: NotRequired[List[CompositionThumbnailConfigurationOutputTypeDef]]

class ListCompositionsResponseTypeDef(TypedDict):
    compositions: List[CompositionSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class S3DestinationConfigurationTypeDef(TypedDict):
    storageConfigurationArn: str
    encoderConfigurationArns: Sequence[str]
    recordingConfiguration: NotRequired[RecordingConfigurationTypeDef]
    thumbnailConfigurations: NotRequired[Sequence[CompositionThumbnailConfigurationUnionTypeDef]]

class CreateEncoderConfigurationResponseTypeDef(TypedDict):
    encoderConfiguration: EncoderConfigurationTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class GetEncoderConfigurationResponseTypeDef(TypedDict):
    encoderConfiguration: EncoderConfigurationTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class ListStorageConfigurationsResponseTypeDef(TypedDict):
    storageConfigurations: List[StorageConfigurationSummaryTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef
    nextToken: NotRequired[str]

class CreateStorageConfigurationResponseTypeDef(TypedDict):
    storageConfiguration: StorageConfigurationTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class GetStorageConfigurationResponseTypeDef(TypedDict):
    storageConfiguration: StorageConfigurationTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class CreateStageResponseTypeDef(TypedDict):
    stage: StageTypeDef
    participantTokens: List[ParticipantTokenTypeDef]
    ResponseMetadata: ResponseMetadataTypeDef

class GetStageResponseTypeDef(TypedDict):
    stage: StageTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class UpdateStageResponseTypeDef(TypedDict):
    stage: StageTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class CreateStageRequestTypeDef(TypedDict):
    name: NotRequired[str]
    participantTokenConfigurations: NotRequired[Sequence[ParticipantTokenConfigurationTypeDef]]
    tags: NotRequired[Mapping[str, str]]
    autoParticipantRecordingConfiguration: NotRequired[
        AutoParticipantRecordingConfigurationUnionTypeDef
    ]

class UpdateStageRequestTypeDef(TypedDict):
    arn: str
    name: NotRequired[str]
    autoParticipantRecordingConfiguration: NotRequired[
        AutoParticipantRecordingConfigurationUnionTypeDef
    ]

class DestinationConfigurationOutputTypeDef(TypedDict):
    name: NotRequired[str]
    channel: NotRequired[ChannelDestinationConfigurationTypeDef]
    s3: NotRequired[S3DestinationConfigurationOutputTypeDef]

S3DestinationConfigurationUnionTypeDef = Union[
    S3DestinationConfigurationTypeDef, S3DestinationConfigurationOutputTypeDef
]
DestinationTypeDef = TypedDict(
    "DestinationTypeDef",
    {
        "id": str,
        "state": DestinationStateType,
        "configuration": DestinationConfigurationOutputTypeDef,
        "startTime": NotRequired[datetime],
        "endTime": NotRequired[datetime],
        "detail": NotRequired[DestinationDetailTypeDef],
    },
)

class DestinationConfigurationTypeDef(TypedDict):
    name: NotRequired[str]
    channel: NotRequired[ChannelDestinationConfigurationTypeDef]
    s3: NotRequired[S3DestinationConfigurationUnionTypeDef]

class CompositionTypeDef(TypedDict):
    arn: str
    stageArn: str
    state: CompositionStateType
    layout: LayoutConfigurationTypeDef
    destinations: List[DestinationTypeDef]
    tags: NotRequired[Dict[str, str]]
    startTime: NotRequired[datetime]
    endTime: NotRequired[datetime]

DestinationConfigurationUnionTypeDef = Union[
    DestinationConfigurationTypeDef, DestinationConfigurationOutputTypeDef
]

class GetCompositionResponseTypeDef(TypedDict):
    composition: CompositionTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class StartCompositionResponseTypeDef(TypedDict):
    composition: CompositionTypeDef
    ResponseMetadata: ResponseMetadataTypeDef

class StartCompositionRequestTypeDef(TypedDict):
    stageArn: str
    destinations: Sequence[DestinationConfigurationUnionTypeDef]
    idempotencyToken: NotRequired[str]
    layout: NotRequired[LayoutConfigurationTypeDef]
    tags: NotRequired[Mapping[str, str]]



"""
Type annotations for ivs-realtime service Client.

[Documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from mypy_boto3_ivs_realtime.client import IvsrealtimeClient

    session = Session()
    client: IvsrealtimeClient = session.client("ivs-realtime")
    ```
"""

from __future__ import annotations

import sys
from typing import Any, overload

from botocore.client import BaseClient, ClientMeta
from botocore.errorfactory import BaseClientExceptions
from botocore.exceptions import ClientError as BotocoreClientError

from .paginator import (
    ListIngestConfigurationsPaginator,
    ListParticipantReplicasPaginator,
    ListPublicKeysPaginator,
)
from .type_defs import (
    CreateEncoderConfigurationRequestTypeDef,
    CreateEncoderConfigurationResponseTypeDef,
    CreateIngestConfigurationRequestTypeDef,
    CreateIngestConfigurationResponseTypeDef,
    CreateParticipantTokenRequestTypeDef,
    CreateParticipantTokenResponseTypeDef,
    CreateStageRequestTypeDef,
    CreateStageResponseTypeDef,
    CreateStorageConfigurationRequestTypeDef,
    CreateStorageConfigurationResponseTypeDef,
    DeleteEncoderConfigurationRequestTypeDef,
    DeleteIngestConfigurationRequestTypeDef,
    DeletePublicKeyRequestTypeDef,
    DeleteStageRequestTypeDef,
    DeleteStorageConfigurationRequestTypeDef,
    DisconnectParticipantRequestTypeDef,
    GetCompositionRequestTypeDef,
    GetCompositionResponseTypeDef,
    GetEncoderConfigurationRequestTypeDef,
    GetEncoderConfigurationResponseTypeDef,
    GetIngestConfigurationRequestTypeDef,
    GetIngestConfigurationResponseTypeDef,
    GetParticipantRequestTypeDef,
    GetParticipantResponseTypeDef,
    GetPublicKeyRequestTypeDef,
    GetPublicKeyResponseTypeDef,
    GetStageRequestTypeDef,
    GetStageResponseTypeDef,
    GetStageSessionRequestTypeDef,
    GetStageSessionResponseTypeDef,
    GetStorageConfigurationRequestTypeDef,
    GetStorageConfigurationResponseTypeDef,
    ImportPublicKeyRequestTypeDef,
    ImportPublicKeyResponseTypeDef,
    ListCompositionsRequestTypeDef,
    ListCompositionsResponseTypeDef,
    ListEncoderConfigurationsRequestTypeDef,
    ListEncoderConfigurationsResponseTypeDef,
    ListIngestConfigurationsRequestTypeDef,
    ListIngestConfigurationsResponseTypeDef,
    ListParticipantEventsRequestTypeDef,
    ListParticipantEventsResponseTypeDef,
    ListParticipantReplicasRequestTypeDef,
    ListParticipantReplicasResponseTypeDef,
    ListParticipantsRequestTypeDef,
    ListParticipantsResponseTypeDef,
    ListPublicKeysRequestTypeDef,
    ListPublicKeysResponseTypeDef,
    ListStageSessionsRequestTypeDef,
    ListStageSessionsResponseTypeDef,
    ListStagesRequestTypeDef,
    ListStagesResponseTypeDef,
    ListStorageConfigurationsRequestTypeDef,
    ListStorageConfigurationsResponseTypeDef,
    ListTagsForResourceRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    StartCompositionRequestTypeDef,
    StartCompositionResponseTypeDef,
    StartParticipantReplicationRequestTypeDef,
    StartParticipantReplicationResponseTypeDef,
    StopCompositionRequestTypeDef,
    StopParticipantReplicationRequestTypeDef,
    StopParticipantReplicationResponseTypeDef,
    TagResourceRequestTypeDef,
    UntagResourceRequestTypeDef,
    UpdateIngestConfigurationRequestTypeDef,
    UpdateIngestConfigurationResponseTypeDef,
    UpdateStageRequestTypeDef,
    UpdateStageResponseTypeDef,
)

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
    from builtins import type as Type
    from collections.abc import Mapping
else:
    from typing import Dict, Mapping, Type
if sys.version_info >= (3, 12):
    from typing import Literal, Unpack
else:
    from typing_extensions import Literal, Unpack


__all__ = ("IvsrealtimeClient",)


class Exceptions(BaseClientExceptions):
    AccessDeniedException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    ConflictException: Type[BotocoreClientError]
    InternalServerException: Type[BotocoreClientError]
    PendingVerification: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]
    ServiceQuotaExceededException: Type[BotocoreClientError]
    ValidationException: Type[BotocoreClientError]


class IvsrealtimeClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime.html#Ivsrealtime.Client)
    [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        IvsrealtimeClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime.html#Ivsrealtime.Client)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#exceptions)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/can_paginate.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#can_paginate)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/generate_presigned_url.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#generate_presigned_url)
        """

    def create_encoder_configuration(
        self, **kwargs: Unpack[CreateEncoderConfigurationRequestTypeDef]
    ) -> CreateEncoderConfigurationResponseTypeDef:
        """
        Creates an EncoderConfiguration object.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/create_encoder_configuration.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#create_encoder_configuration)
        """

    def create_ingest_configuration(
        self, **kwargs: Unpack[CreateIngestConfigurationRequestTypeDef]
    ) -> CreateIngestConfigurationResponseTypeDef:
        """
        Creates a new IngestConfiguration resource, used to specify the ingest protocol
        for a stage.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/create_ingest_configuration.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#create_ingest_configuration)
        """

    def create_participant_token(
        self, **kwargs: Unpack[CreateParticipantTokenRequestTypeDef]
    ) -> CreateParticipantTokenResponseTypeDef:
        """
        Creates an additional token for a specified stage.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/create_participant_token.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#create_participant_token)
        """

    def create_stage(
        self, **kwargs: Unpack[CreateStageRequestTypeDef]
    ) -> CreateStageResponseTypeDef:
        """
        Creates a new stage (and optionally participant tokens).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/create_stage.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#create_stage)
        """

    def create_storage_configuration(
        self, **kwargs: Unpack[CreateStorageConfigurationRequestTypeDef]
    ) -> CreateStorageConfigurationResponseTypeDef:
        """
        Creates a new storage configuration, used to enable recording to Amazon S3.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/create_storage_configuration.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#create_storage_configuration)
        """

    def delete_encoder_configuration(
        self, **kwargs: Unpack[DeleteEncoderConfigurationRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Deletes an EncoderConfiguration resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/delete_encoder_configuration.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#delete_encoder_configuration)
        """

    def delete_ingest_configuration(
        self, **kwargs: Unpack[DeleteIngestConfigurationRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Deletes a specified IngestConfiguration, so it can no longer be used to
        broadcast.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/delete_ingest_configuration.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#delete_ingest_configuration)
        """

    def delete_public_key(self, **kwargs: Unpack[DeletePublicKeyRequestTypeDef]) -> Dict[str, Any]:
        """
        Deletes the specified public key used to sign stage participant tokens.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/delete_public_key.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#delete_public_key)
        """

    def delete_stage(self, **kwargs: Unpack[DeleteStageRequestTypeDef]) -> Dict[str, Any]:
        """
        Shuts down and deletes the specified stage (disconnecting all participants).

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/delete_stage.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#delete_stage)
        """

    def delete_storage_configuration(
        self, **kwargs: Unpack[DeleteStorageConfigurationRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Deletes the storage configuration for the specified ARN.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/delete_storage_configuration.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#delete_storage_configuration)
        """

    def disconnect_participant(
        self, **kwargs: Unpack[DisconnectParticipantRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Disconnects a specified participant from a specified stage.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/disconnect_participant.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#disconnect_participant)
        """

    def get_composition(
        self, **kwargs: Unpack[GetCompositionRequestTypeDef]
    ) -> GetCompositionResponseTypeDef:
        """
        Get information about the specified Composition resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/get_composition.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#get_composition)
        """

    def get_encoder_configuration(
        self, **kwargs: Unpack[GetEncoderConfigurationRequestTypeDef]
    ) -> GetEncoderConfigurationResponseTypeDef:
        """
        Gets information about the specified EncoderConfiguration resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/get_encoder_configuration.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#get_encoder_configuration)
        """

    def get_ingest_configuration(
        self, **kwargs: Unpack[GetIngestConfigurationRequestTypeDef]
    ) -> GetIngestConfigurationResponseTypeDef:
        """
        Gets information about the specified IngestConfiguration.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/get_ingest_configuration.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#get_ingest_configuration)
        """

    def get_participant(
        self, **kwargs: Unpack[GetParticipantRequestTypeDef]
    ) -> GetParticipantResponseTypeDef:
        """
        Gets information about the specified participant token.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/get_participant.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#get_participant)
        """

    def get_public_key(
        self, **kwargs: Unpack[GetPublicKeyRequestTypeDef]
    ) -> GetPublicKeyResponseTypeDef:
        """
        Gets information for the specified public key.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/get_public_key.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#get_public_key)
        """

    def get_stage(self, **kwargs: Unpack[GetStageRequestTypeDef]) -> GetStageResponseTypeDef:
        """
        Gets information for the specified stage.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/get_stage.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#get_stage)
        """

    def get_stage_session(
        self, **kwargs: Unpack[GetStageSessionRequestTypeDef]
    ) -> GetStageSessionResponseTypeDef:
        """
        Gets information for the specified stage session.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/get_stage_session.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#get_stage_session)
        """

    def get_storage_configuration(
        self, **kwargs: Unpack[GetStorageConfigurationRequestTypeDef]
    ) -> GetStorageConfigurationResponseTypeDef:
        """
        Gets the storage configuration for the specified ARN.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/get_storage_configuration.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#get_storage_configuration)
        """

    def import_public_key(
        self, **kwargs: Unpack[ImportPublicKeyRequestTypeDef]
    ) -> ImportPublicKeyResponseTypeDef:
        """
        Import a public key to be used for signing stage participant tokens.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/import_public_key.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#import_public_key)
        """

    def list_compositions(
        self, **kwargs: Unpack[ListCompositionsRequestTypeDef]
    ) -> ListCompositionsResponseTypeDef:
        """
        Gets summary information about all Compositions in your account, in the AWS
        region where the API request is processed.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/list_compositions.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#list_compositions)
        """

    def list_encoder_configurations(
        self, **kwargs: Unpack[ListEncoderConfigurationsRequestTypeDef]
    ) -> ListEncoderConfigurationsResponseTypeDef:
        """
        Gets summary information about all EncoderConfigurations in your account, in
        the AWS region where the API request is processed.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/list_encoder_configurations.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#list_encoder_configurations)
        """

    def list_ingest_configurations(
        self, **kwargs: Unpack[ListIngestConfigurationsRequestTypeDef]
    ) -> ListIngestConfigurationsResponseTypeDef:
        """
        Lists all IngestConfigurations in your account, in the AWS region where the API
        request is processed.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/list_ingest_configurations.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#list_ingest_configurations)
        """

    def list_participant_events(
        self, **kwargs: Unpack[ListParticipantEventsRequestTypeDef]
    ) -> ListParticipantEventsResponseTypeDef:
        """
        Lists events for a specified participant that occurred during a specified stage
        session.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/list_participant_events.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#list_participant_events)
        """

    def list_participant_replicas(
        self, **kwargs: Unpack[ListParticipantReplicasRequestTypeDef]
    ) -> ListParticipantReplicasResponseTypeDef:
        """
        Lists all the replicas for a participant from a source stage.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/list_participant_replicas.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#list_participant_replicas)
        """

    def list_participants(
        self, **kwargs: Unpack[ListParticipantsRequestTypeDef]
    ) -> ListParticipantsResponseTypeDef:
        """
        Lists all participants in a specified stage session.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/list_participants.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#list_participants)
        """

    def list_public_keys(
        self, **kwargs: Unpack[ListPublicKeysRequestTypeDef]
    ) -> ListPublicKeysResponseTypeDef:
        """
        Gets summary information about all public keys in your account, in the AWS
        region where the API request is processed.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/list_public_keys.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#list_public_keys)
        """

    def list_stage_sessions(
        self, **kwargs: Unpack[ListStageSessionsRequestTypeDef]
    ) -> ListStageSessionsResponseTypeDef:
        """
        Gets all sessions for a specified stage.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/list_stage_sessions.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#list_stage_sessions)
        """

    def list_stages(self, **kwargs: Unpack[ListStagesRequestTypeDef]) -> ListStagesResponseTypeDef:
        """
        Gets summary information about all stages in your account, in the AWS region
        where the API request is processed.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/list_stages.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#list_stages)
        """

    def list_storage_configurations(
        self, **kwargs: Unpack[ListStorageConfigurationsRequestTypeDef]
    ) -> ListStorageConfigurationsResponseTypeDef:
        """
        Gets summary information about all storage configurations in your account, in
        the AWS region where the API request is processed.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/list_storage_configurations.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#list_storage_configurations)
        """

    def list_tags_for_resource(
        self, **kwargs: Unpack[ListTagsForResourceRequestTypeDef]
    ) -> ListTagsForResourceResponseTypeDef:
        """
        Gets information about AWS tags for the specified ARN.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/list_tags_for_resource.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#list_tags_for_resource)
        """

    def start_composition(
        self, **kwargs: Unpack[StartCompositionRequestTypeDef]
    ) -> StartCompositionResponseTypeDef:
        """
        Starts a Composition from a stage based on the configuration provided in the
        request.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/start_composition.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#start_composition)
        """

    def start_participant_replication(
        self, **kwargs: Unpack[StartParticipantReplicationRequestTypeDef]
    ) -> StartParticipantReplicationResponseTypeDef:
        """
        Starts replicating a publishing participant from a source stage to a
        destination stage.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/start_participant_replication.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#start_participant_replication)
        """

    def stop_composition(self, **kwargs: Unpack[StopCompositionRequestTypeDef]) -> Dict[str, Any]:
        """
        Stops and deletes a Composition resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/stop_composition.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#stop_composition)
        """

    def stop_participant_replication(
        self, **kwargs: Unpack[StopParticipantReplicationRequestTypeDef]
    ) -> StopParticipantReplicationResponseTypeDef:
        """
        Stops a replicated participant session.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/stop_participant_replication.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#stop_participant_replication)
        """

    def tag_resource(self, **kwargs: Unpack[TagResourceRequestTypeDef]) -> Dict[str, Any]:
        """
        Adds or updates tags for the AWS resource with the specified ARN.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/tag_resource.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#tag_resource)
        """

    def untag_resource(self, **kwargs: Unpack[UntagResourceRequestTypeDef]) -> Dict[str, Any]:
        """
        Removes tags from the resource with the specified ARN.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/untag_resource.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#untag_resource)
        """

    def update_ingest_configuration(
        self, **kwargs: Unpack[UpdateIngestConfigurationRequestTypeDef]
    ) -> UpdateIngestConfigurationResponseTypeDef:
        """
        Updates a specified IngestConfiguration.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/update_ingest_configuration.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#update_ingest_configuration)
        """

    def update_stage(
        self, **kwargs: Unpack[UpdateStageRequestTypeDef]
    ) -> UpdateStageResponseTypeDef:
        """
        Updates a stage's configuration.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/update_stage.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#update_stage)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_ingest_configurations"]
    ) -> ListIngestConfigurationsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/get_paginator.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_participant_replicas"]
    ) -> ListParticipantReplicasPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/get_paginator.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_public_keys"]
    ) -> ListPublicKeysPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ivs-realtime/client/get_paginator.html)
        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/client/#get_paginator)
        """



"""
Main interface for ivs-realtime service.

[Documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ivs_realtime/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from mypy_boto3_ivs_realtime import (
        Client,
        IvsrealtimeClient,
        ListIngestConfigurationsPaginator,
        ListParticipantReplicasPaginator,
        ListPublicKeysPaginator,
    )

    session = Session()
    client: IvsrealtimeClient = session.client("ivs-realtime")

    list_ingest_configurations_paginator: ListIngestConfigurationsPaginator = client.get_paginator("list_ingest_configurations")
    list_participant_replicas_paginator: ListParticipantReplicasPaginator = client.get_paginator("list_participant_replicas")
    list_public_keys_paginator: ListPublicKeysPaginator = client.get_paginator("list_public_keys")
    ```
"""

from .client import IvsrealtimeClient
from .paginator import (
    ListIngestConfigurationsPaginator,
    ListParticipantReplicasPaginator,
    ListPublicKeysPaginator,
)

Client = IvsrealtimeClient


__all__ = (
    "Client",
    "IvsrealtimeClient",
    "ListIngestConfigurationsPaginator",
    "ListParticipantReplicasPaginator",
    "ListPublicKeysPaginator",
)
